# conding=utf-8
"""
@project:bayeslibs
@language:Python3
@create:2019/5/30
@author:qianyang<qianyang@aibayes.com>
@description:none
"""
from . import age_gender, emotion, headpose, face

__all__ = ['age_gender', 'emotion', 'headpose', 'face']
