# conding=utf-8
"""
@project:bayeslibs
@language:Python3
@create:2019/5/30
@author:qianyang<qianyang@aibayes.com>
@description:none
"""

TYPE_START = 'start'
TYPE_STOP = 'stop'
TYPE_QUERY = 'query'

MOVE_FORWARD = 'forward'
MOVE_BACK = 'back'
MOVE_LEFT = 'left'
MOVE_RIGHT = 'right'

ROTATE_BACK = 'rotate_back'
ROTATE_LEFT = 'rotate_left'
ROTATE_RIGHT = 'rotate_right'

APOLLO_INI = 'apollo.yaml'

APOLLO_T200 = 'apollo_t200'
IP = 'ip'
PORT = 'port'
NETWORK = 'network'

ACCESS_AUTH = 'access_auth'
APPID = 'appid'
APPKEY = 'appkey'

NAV_POS = 'nav_pos'
P_ELROOM = 'p_elroom'
P_FNROOM = 'p_fnroom'
P_ORIGIN = 'p_origin'

MOTION = 'motion'
MAX_DIST = 'max_dist'
MAX_ANGLE = 'max_angle'
